@@ -36,7 +36,7 @@
 ##'     to be available for further processing.
 ##' @param input.archive A function of the model file path to generate
 ##'     the path in which to archive the input data as RDS. Set to
-##'     NULL not to archive the data.
+##'     FALSE not to archive the data.
 ##' @param args.psn.execute A character string with arguments passed
 ##'     to execute. Default is
 ##'     "-model_dir_name -nm_output=coi,cor,cov,ext,phi,shk,xml".
@@ -242,7 +242,9 @@ NMexec <- function(files,file.pattern,dir,sge=TRUE,input.archive,
         
         files.found <- c(
             list.files(rundir,pattern=sprintf("%s%s",fnExtension(basename(file.mod),""),exts.string)),
-            list.files(rundir,pattern=paste0("(",paste(NMscanTables(file.mod,meta.only=TRUE,as.fun="data.table")[,name],collapse="|"),")"))
+            list.files(rundir,pattern=paste0("^(",paste(
+                                                     NMscanTables(file.mod,meta.only=TRUE,as.fun="data.table")[,name]
+                                                    ,collapse="|"),")$"))
         )
         ## make sure files.found does not contain input control stream or input data
         if(length(files.found)){
