@@ -18,6 +18,8 @@
 
 NMsim_typical <- function(file.sim,file.mod,data.sim,return.text=FALSE){
 
+    message("NMsim_typical() is deprecated. Use `typical=TRUE` in combination with other simulation methods instead. The old `method.sim=NMsim_typical` is equivalent to combining `typical=TRUE` with the default simulation method `method.sim=NMsim_default`.")
+    
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
 
     par.type <- NULL
@@ -28,11 +30,30 @@ NMsim_typical <- function(file.sim,file.mod,data.sim,return.text=FALSE){
 
     files.needed.def <- NMsim_default(file.sim=file.sim,file.mod,data.sim)
     lines.sim <- readLines(file.sim)
+
+### this introduces dependency on file.ext or Netas as
+### arguments. Better keep deprecated NMsim_typical as is. Used in typicalize() instead. 
+
+    ## if(missing(Netas)) Netas <- NULL
+    ## if(missing(file.ext)) file.ext <- NULL
     
+    ## if(is.null(Netas)){        
+    ##     if(is.null(file.ext)){
+    ##         file.ext <- fnExtension(file.mod,"ext")    
+    ##         if(!file.exists(file.ext)){
+    ##             stop("ext file not found and number of Etas not provided. See arguments file.ext and Netas.")
+    ##         } else {
+    ##             extres <- NMreadExt(file.ext,return="pars",as.fun="data.table")
+    ##             Netas <- extres[par.type=="OMEGA",max(i)]
+    ##         }
+    ##     }
+    ## }
+
+
     extres <- NMreadExt(fnExtension(file.mod,"ext"),return="pars",as.fun="data.table")
     Netas <- extres[par.type=="OMEGA",max(i)]
-
-    lines.omega <- paste(c("$OMEGA",rep("0 FIX",Netas,"")),collapse="\n")
+    
+    lines.omega <- paste(c("$OMEGA",rep("0 FIX",Netas),""),collapse="\n")
     lines.sim <- NMdata:::NMwriteSectionOne(lines=lines.sim,section="omega",newlines=lines.omega,backup=FALSE,quiet=TRUE)
 
     if(return.text){
