@@ -10,7 +10,8 @@ if(FALSE){
     ## additional args
     scale.par <- "var"
 
-    data <- NMscanData(system.file("examples/simulations/xgxr014_singlesubj1.lst",package="NMsim"),merge.by.row=FALSE,as.fun="data.table")
+    data <- NMscanData("testData/simres/xgxr014_singlesubj1.lst",merge.by.row=FALSE,as.fun="data.table")
+    set.seed(2)
     data1 <- addResVar(data=data
                       ,path.ext = system.file("examples/nonmem/xgxr014.ext",package="NMsim")
                       ,prop = 1
@@ -18,6 +19,7 @@ if(FALSE){
                       ,par.type = "SIGMA"
                       ,log = FALSE)
 
+    
     ggplot(data1,aes(TIME,IPRED,colour=dose)) + geom_line() +
         geom_point(aes(TIME,IPREDVAR))+
         facet_wrap(~regimen,scales="free")
